| Title: | 'NEOS' Plug-in for the 'R' Optimization Interface |
|---|---|
| Description: | Enhances the 'R' Optimization Infrastructure ('ROI') package with a connection to the 'neos' server. 'ROI' optimization problems can be directly be sent to the 'neos' server and solution obtained in the typical 'ROI' style. |
| Authors: | Ronald Hochreiter [aut], Florian Schwendinger [aut, cre] |
| Maintainer: | Florian Schwendinger <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0-0 |
| Built: | 2026-06-07 08:29:09 UTC |
| Source: | https://github.com/r-forge/roi |
The control variables for ROI.plugin.neos.
user |
a character string giving the username. |
email |
a character string giving the email address. |
dry_run |
a logical if |
wait |
a logical indicating whether the R interpreter should wait for the
command to finish, or run it asynchronously. If |
## Not run: library(ROI) mat <- matrix(c(3, 4, 2, 2, 1, 2, 1, 3, 2), nrow=3, byrow=TRUE) x <- OP(objective = c(2, 4, 3), constraints = L_constraint(L = mat, dir = c("<=", "<=", "<="), rhs = c(60, 40, 80)), maximum = TRUE) opt <- ROI_solve(x, solver = "neos", method = "scip") opt ## Optimal solution found. ## The objective value is: 7.666667e+01 solution(opt) ## [1] 0.000000 6.666667 16.666667 ## End(Not run)## Not run: library(ROI) mat <- matrix(c(3, 4, 2, 2, 1, 2, 1, 3, 2), nrow=3, byrow=TRUE) x <- OP(objective = c(2, 4, 3), constraints = L_constraint(L = mat, dir = c("<=", "<=", "<="), rhs = c(60, 40, 80)), maximum = TRUE) opt <- ROI_solve(x, solver = "neos", method = "scip") opt ## Optimal solution found. ## The objective value is: 7.666667e+01 solution(opt) ## [1] 0.000000 6.666667 16.666667 ## End(Not run)